@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.708';
+our $VERSION = '1.710';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -144,7 +144,7 @@ sub __copy_orig_list {
             }
             if ( $self->{color} ) {
                 s/\x{feff}//g;
-                s/\e\[[\d;]*m/\x{feff}/msg;
+                s/\e\[[\d;]*m/\x{feff}/g;
             }
             s/\t/ /g;
             s/[\x{000a}-\x{000d}\x{0085}\x{2028}\x{2029}]+/\ \ /g; # \v 5.10
@@ -659,7 +659,7 @@ sub __prepare_promptline {
         my $subseq = $self->{tabs_info}[1] ? $self->{tabs_info}[1] : 0;
         $prompt .= line_fold(
             $self->{info}, $self->{avail_width},
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color} }
+            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 1 }
         );
     }
     if ( length $self->{prompt} ) {
@@ -670,7 +670,7 @@ sub __prepare_promptline {
         my $subseq = $self->{tabs_prompt}[1] ? $self->{tabs_prompt}[1] : 0;
         $prompt .= line_fold(
             $self->{prompt}, $self->{avail_width},
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color} }
+            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 1 }
         );
     }
     if ( $prompt eq '' ) {
@@ -697,7 +697,7 @@ sub __prepare_page_number {
         else {
             $self->{footer_fmt} = '--- Page %0' . $pp_total_w . 'd/' . $pp_total . ' ---';
         }
-        if ( length( sprintf $self->{footer_fmt}, $pp_total ) > $self->{avail_width} ) { # color
+        if ( print_columns( sprintf $self->{footer_fmt}, $pp_total ) > $self->{avail_width} ) { # color, length
             $self->{footer_fmt} = '%0' . $pp_total_w . 'd/' . $pp_total;
             if ( length( sprintf $self->{footer_fmt}, $pp_total ) > $self->{avail_width} ) {
                 $pp_total_w = $self->{avail_width} if $pp_total_w > $self->{avail_width};
@@ -800,7 +800,7 @@ sub __wr_screen {
         $self->__goto( $self->{avail_height_idx} + $self->{pp_row}, 0 );
         my $pp_line = sprintf $self->{footer_fmt}, int( $self->{first_page_row} / $self->{avail_height} ) + 1;
         print $pp_line;
-        $self->{i_col} += length $pp_line;
+        $self->{i_col} += print_columns( $pp_line );
     }
     for my $row ( $self->{first_page_row} .. $self->{last_page_row} ) {
         for my $col ( 0 .. $#{$self->{rc2idx}[$row]} ) {
@@ -1196,7 +1196,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.708
+Version 1.710
 
 =cut
 
