@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.708';
+our $VERSION = '1.710';
 
 use Exporter qw( import );
 
@@ -31,19 +31,19 @@ my $cache = [];
 
 
 sub char_width {
-    # $_[0] == ord $char
+    my $c = $_[0];
     my $min = 0;
     my $mid;
     my $max = $#$table;
-    if ($_[0] < $table->[0][0] || $_[0] > $table->[$max][1] ) {
+    if ($c < $table->[0][0] || $c > $table->[$max][1] ) {
         return 1;
     }
     while ( $max >= $min ) {
         $mid = int( ( $min + $max ) / 2 );
-        if ( $_[0] > $table->[$mid][1] ) {
+        if ( $c > $table->[$mid][1] ) {
             $min = $mid + 1;
         }
-        elsif ( $_[0] < $table->[$mid][0] ) {
+        elsif ( $c < $table->[$mid][0] ) {
             $max = $mid - 1;
         }
         else {
@@ -55,10 +55,10 @@ sub char_width {
 
 
 sub print_columns {
-    # $_[0] == string
+    my $str = $_[0];
     my $width = 0;
-    for my $i ( 0 .. ( length( $_[0] ) - 1 ) ) {
-        my $c = ord substr $_[0], $i, 1;
+    for my $i ( 0 .. ( length( $str ) - 1 ) ) {
+        my $c = ord substr $str, $i, 1;
         if ( ! defined $cache->[$c] ) {
             $cache->[$c] = char_width( $c );
         }
@@ -69,42 +69,40 @@ sub print_columns {
 
 
 sub cut_to_printwidth {
-    # $_[0] == string
-    # $_[1] == available width
-    # $_[2] == return the rest (yes/no)
+    my ( $str, $avail_w, $return_rest ) = @_;
     my $count = 0;
     my $total = 0;
-    for my $i ( 0 .. ( length( $_[0] ) - 1 ) ) {
-        my $c = ord substr $_[0], $i, 1;
+    for my $i ( 0 .. ( length( $str ) - 1 ) ) {
+        my $c = ord substr $str, $i, 1;
         if ( ! defined $cache->[$c] ) {
             $cache->[$c] = char_width( $c )
         }
-        if ( ( $total = $total + $cache->[$c] ) > $_[1] ) {
-            if ( ( $total - $cache->[$c] ) < $_[1] ) {
-                return substr( $_[0], 0, $count ) . ' ', substr( $_[0], $count ) if $_[2];
-                return substr( $_[0], 0, $count ) . ' ';
+        if ( ( $total = $total + $cache->[$c] ) > $avail_w ) {
+            if ( ( $total - $cache->[$c] ) < $avail_w ) {
+                return substr( $str, 0, $count ) . ' ', substr( $str, $count ) if $return_rest;
+                return substr( $str, 0, $count ) . ' ';
             }
-            return substr( $_[0], 0, $count ), substr( $_[0], $count ) if $_[2];
-            return substr( $_[0], 0, $count );
+            return substr( $str, 0, $count ), substr( $str, $count ) if $return_rest;
+            return substr( $str, 0, $count );
 
         }
         ++$count;
     }
-    return $_[0], '' if $_[2];
-    return $_[0];
+    return $str, '' if $return_rest;
+    return $str;
 }
 
 
 sub line_fold {
-    my ( $string, $avail_width, $opt ) = @_; #copy $string
-    return $string if ! defined $string || ! length $string;
+    my ( $str, $avail_w, $opt ) = @_; #copy $str
+    return $str if ! defined $str || ! length $str;
     for ( $opt->{init_tab}, $opt->{subseq_tab} ) {
         if ( defined $_ && length $_ ) {
             s/\t/ /g;
             s/[\x{000a}-\x{000d}\x{0085}\x{2028}\x{2029}]+/\ \ /g;
             s/[\p{Cc}\p{Noncharacter_Code_Point}\p{Cs}]//g;
-            if ( length > $avail_width / 4 ) {
-                $_ = cut_to_printwidth( $_, int( $avail_width / 2 ) );
+            if ( length > $avail_w / 4 ) {
+                $_ = cut_to_printwidth( $_, int( $avail_w / 2 ) );
             }
         }
         else {
@@ -113,26 +111,26 @@ sub line_fold {
     }
     my @color;
     if ( $opt->{color} ) {
-        $string =~ s/\x{feff}//g;
-        $string =~ s/(\e\[[\d;]*m)/push( @color, $1 ) && "\x{feff}"/ge; # ms
+        $str =~ s/\x{feff}//g;
+        $str =~ s/(\e\[[\d;]*m)/push( @color, $1 ) && "\x{feff}"/ge;
     }
-    $string =~ s/\t/ /g;
-    $string =~ s/[^\x{0a}\x{0b}\x{0c}\x{0d}\x{85}\P{Cc}]//g; # remove control chars but keep vertical spaces
-    $string =~ s/[\p{Noncharacter_Code_Point}\p{Cs}]//g;
+    $str =~ s/\t/ /g;
+    $str =~ s/[^\x{0a}\x{0b}\x{0c}\x{0d}\x{85}\P{Cc}]//g; # remove control chars but keep vertical spaces
+    $str =~ s/[\p{Noncharacter_Code_Point}\p{Cs}]//g;
     my $regex = qr/\x{0d}\x{0a}|[\x{000a}-\x{000d}\x{0085}\x{2028}\x{2029}]/; # \R 5.10
-    if ( $string !~ /$regex/ && print_columns( $opt->{init_tab} . $string ) <= $avail_width && ! @color ) {
-        return $opt->{init_tab} . $string;
+    if ( $str !~ /$regex/ && print_columns( $opt->{init_tab} . $str ) <= $avail_w && ! @color ) {
+        return $opt->{init_tab} . $str;
     }
     my @paragraphs;
 
-    for my $row ( split /$regex/, $string, -1 ) { # -1 to keep trailing empty fields
+    for my $row ( split /$regex/, $str, -1 ) { # -1 to keep trailing empty fields
         my @lines;
         $row =~ s/\s+\z//;
         my @words = split( /(?<=\S)(?=\s)/, $row );
         my $line = $opt->{init_tab};
 
         for my $i ( 0 .. $#words ) {
-            if ( print_columns( $line . $words[$i] ) <= $avail_width ) {
+            if ( print_columns( $line . $words[$i] ) <= $avail_w ) {
                 $line .= $words[$i];
             }
             else {
@@ -145,18 +143,28 @@ sub line_fold {
                     $words[$i] =~ s/^\s+//;
                     $tmp = $opt->{subseq_tab} . $words[$i];
                 }
-                ( $line, my $remainder ) = cut_to_printwidth( $tmp, $avail_width, 1 );
+                ( $line, my $remainder ) = cut_to_printwidth( $tmp, $avail_w, 1 );
                 while ( length $remainder ) {
                     push( @lines, $line );
                     $tmp = $opt->{subseq_tab} . $remainder;
-                    ( $line, $remainder ) = cut_to_printwidth( $tmp, $avail_width, 1 );
+                    ( $line, $remainder ) = cut_to_printwidth( $tmp, $avail_w, 1 );
                 }
             }
             if ( $i == $#words ) {
                 push( @lines, $line );
             }
         }
-        push( @paragraphs, join( "\n", @lines ) );
+        if ( $opt->{join} ) {
+            push( @paragraphs, join( "\n", @lines ) );
+        }
+        else {
+            if ( @lines ) {
+                push( @paragraphs, @lines );
+            }
+            else {
+                push( @paragraphs, '' );
+            }
+        }
     }
     if ( @color ) {
         for my $paragraph ( @paragraphs ) {
@@ -167,7 +175,12 @@ sub line_fold {
         }
         $paragraphs[-1] .= normal();
     }
-    return join( "\n", @paragraphs );
+    if ( $opt->{join} ) {
+        return join( "\n", @paragraphs );
+    }
+    else {
+        return @paragraphs;
+    }
 }
 
 
